/**
* @license Apache-2.0
*
* Copyright (c) 2021 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

/* eslint-disable no-restricted-syntax, max-classes-per-file */

'use strict';

// MODULES //

var tape = require( 'tape' );
var isClass = require( './../../lib' );


// TESTS //

tape( 'the function returns `true` if provided an ES2015 class', function test( t ) {
	var Rectangle = class {};
	t.strictEqual( isClass( Rectangle ), true, 'returns true' );

	t.strictEqual( isClass( class Person {} ), true, 'returns true' );
	t.end();
});
