/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

var isAbsolutePath = require( './../lib' );

var bool = isAbsolutePath.posix( '/foo/bar/baz' );
console.log( bool );
// => true

bool = isAbsolutePath.posix( '/foo/..' );
console.log( bool );
// => true

bool = isAbsolutePath.posix( 'foo/' );
console.log( bool );
// => false

bool = isAbsolutePath.posix( 'foo' );
console.log( bool );
// => false

bool = isAbsolutePath.posix( '.' );
console.log( bool );
// => false

bool = isAbsolutePath.posix( '' );
console.log( bool );
// => false

bool = isAbsolutePath.win32( 'C:\\foo\\bar\\baz' );
console.log( bool );
// => true

bool = isAbsolutePath.win32( '//server' );
console.log( bool );
// => true

bool = isAbsolutePath.win32( '\\\\server' );
console.log( bool );
// => true

bool = isAbsolutePath.win32( 'C:/foo/bar/baz' );
console.log( bool );
// => true

bool = isAbsolutePath.win32( '/foo/..' );
console.log( bool );
// => true

bool = isAbsolutePath.win32( 'foo\\bar\\baz' );
console.log( bool );
// => false

bool = isAbsolutePath.win32( 'foo/bar/baz' );
console.log( bool );
// => false

bool = isAbsolutePath.win32( 'foo/..' );
console.log( bool );
// => false

bool = isAbsolutePath.win32( '.' );
console.log( bool );
// => false

bool = isAbsolutePath.win32( '' );
console.log( bool );
// => false
