/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

/* eslint-disable no-new-wrappers */

'use strict';

var hasSymbolSupport = require( './../../has-symbol-support' );
var Number = require( '@stdlib/number/ctor' );
var Symbol = require( '@stdlib/symbol/ctor' );
var isnan = require( './../lib' );

console.log( isnan( NaN ) );
// => true

console.log( isnan( new Number( NaN ) ) );
// => true

console.log( isnan( 5 ) );
// => false

console.log( isnan( '5' ) );
// => false

console.log( isnan( null ) );
// => false

if ( hasSymbolSupport() ) {
	console.log( isnan( Symbol( 'NaN' ) ) );
	// => false
}
