/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var isPrimitive = require( './../../is-primitive' );
var isFunction = require( './../../is-function' );
var ITERATOR = require( '@stdlib/symbol/iterator' );
var isIteratorLike = require( './../../is-iterator-like' );


// MAIN //

/**
* Tests if a value is iterable-like.
*
* @param {*} value - value to test
* @returns {boolean} boolean indicating whether a value is iterable-like
*
* @example
* var bool = isIterableLike( [] );
* // returns <boolean>
*
* @example
* var bool = isIterableLike( {} );
* // returns false
*
* @example
* var bool = isIterableLike( null );
* // returns false
*/
function isIterableLike( value ) {
	var f;
	if ( isPrimitive( value ) ) {
		return false;
	}
	f = value[ ITERATOR ];
	return (
		isFunction( f ) &&
		f.length === 0 &&
		isIteratorLike( value[ ITERATOR ]() ) // Why this form? In order to preserve `this`.
	);
}


// EXPORTS //

module.exports = isIterableLike;
