/**
* @license Apache-2.0
*
* Copyright (c) 2021 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var IS_BROWSER = require( './../../is-browser' );
var getGlobal = require( '@stdlib/utils/global' );


// VARIABLES //

var Global = getGlobal();


// MAIN //

/**
* Returns a boolean indicating if an environment is a mobile environment.
*
* ## Notes
*
* -   The implementation checks whether the User Agent contains the string "Mobi" per the [MDN recommendations][1].
*
* [1]: https://developer.mozilla.org/en-US/docs/Web/HTTP/Browser_detection_using_the_user_agent
*
* @private
* @returns {boolean} boolean indicating if an environment is a mobile environment
*/
function isMobile() {
	return (
		IS_BROWSER &&
		Global.navigator &&
		Global.navigator.userAgent &&
		/Mobi/.test( Global.navigator.userAgent )
	);
}


// EXPORTS //

module.exports = isMobile;
